import com.amazon.ask.dispatcher.request.handler.HandlerInput;
import com.amazon.ask.dispatcher.request.handler.RequestHandler;
import com.amazon.ask.model.*;

import static com.amazon.ask.request.Predicates.intentName;

import java.util.Optional;
import java.util.Map;
import static java.lang.Math.random;

public class TipIntent implements RequestHandler {
    static String[] speechTexts = {"Quitting smoking is one of the best things to do for you, your friends and family. " +
            "Keep thinking of your main reason to quit smoking. Let that motivate you! ",
            "If you've quit smoking before, remember the things that helped. Plan to use them again this time. " +
                    "Think about how you'd like to go about quitting smoking, write down your ideas or share them with someone you trust. ",
            "Although setting a quit date can be a bit scary it's a natural step toward quitting. " +
                    "It keeps you moving forward and increases the chances that you will quit for good. ",
            "Think about using a quitting aid, like nicotine patches, nicotine gum, Zyban or Chantix to help you quit. ",
            "To stay motivated keep thinking about why you want to quit smoking. If quitting smoking gets tough, " +
                    "ask for support from those who cares about you. "};
    @Override
    public boolean canHandle(HandlerInput input) {
        return input.matches(intentName("TipIntent"));
    }

    @Override
    public Optional<Response> handle(HandlerInput input) {
        Intent intent = ((IntentRequest) input.getRequestEnvelope().getRequest()).getIntent();
        IntentConfirmationStatus status = intent.getConfirmationStatus();
        Map<String, Object> attributes = input.getAttributesManager().getSessionAttributes();
        int last = Integer.parseInt(attributes.getOrDefault("tipidx", -1).toString());
        int count = Integer.parseInt(attributes.getOrDefault("tipcount", 1).toString());
        switch(status) {
            case NONE:
                attributes.put("tipcount", count + 1);
                int idx;
                do {
                    idx = (int) (random() * speechTexts.length);
                } while(idx == last);
                attributes.put("tipidx", idx);
                if(count % 3 == 0) {
                    return input.getResponseBuilder()
                            .addConfirmIntentDirective(intent)
                            .withSpeech(speechTexts[idx] + " Would you like to set up a quit date? ")
                            .build();
                }
                return input.getResponseBuilder()
                        .withShouldEndSession(false)
                        .withSpeech(speechTexts[idx])
                        .build();
            case CONFIRMED:
                //attributes.put("tipcount", count + 1);
                return input.getResponseBuilder()
                        .withShouldEndSession(false)
                        .withSpeech("To set a quit date, say, today is my quit date or say the date, October 20th, 2018 is my quit date. ")
                        .build();
            case DENIED:
                //attributes.put("tipcount", count + 1);
                return input.getResponseBuilder()
                        .withShouldEndSession(false)
                        .withSpeech("Okay. ")
                        .build();
        }
        return input.getResponseBuilder()
                .withShouldEndSession(false)
                .withSpeech("Okay. ")
                .build();
    }
}